import 'package:flutter_firebase_basic_tools/logic/user_info_form_functions.dart';
import 'package:flutter_firebase_basic_tools/widgets/custom_card.dart';
import 'package:flutter_firebase_basic_tools/widgets/custom_scrollview.dart';
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/widgets/user_info_form_container.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_firebase_basic_tools/flutter_firebase_basic_tools.dart';
import 'package:shared_preferences/shared_preferences.dart';

class Login extends StatefulWidget {
  const Login({
    @required this.topbarBackgroundColor,
    @required this.userInfoFormContainerColor1,
    @required this.userInfoFormContainerColor2,
    @required this.userInfoFormContainerColor3,
    @required this.rememberMeColor,
    @required this.loginButtonColor,
    this.loginButtonGradientColor,
    @required this.forgotButtonColor,
    @required this.registerButtonColor,
    @required this.languagePickerItemsTextColor,
    @required this.backgroundImagePath,
    @required this.languagePicker,
    @required this.openHome,
    @required this.openRegister,
    @required this.openForgotPassword,
    @required this.cardColor,
    @required this.cardElevation,
    @required this.customBackground,
    @required this.textList,
  });

  final Color topbarBackgroundColor;
  final Color userInfoFormContainerColor1;
  final Color userInfoFormContainerColor2;
  final Color userInfoFormContainerColor3;
  final Color rememberMeColor;
  final Color loginButtonColor;
  final LinearGradient loginButtonGradientColor;
  final Color forgotButtonColor;
  final Color registerButtonColor;
  final Color languagePickerItemsTextColor;
  final String backgroundImagePath;
  final bool languagePicker;
  final Function openHome;
  final Function openRegister;
  final Function openForgotPassword;
  final Color cardColor;
  final double cardElevation;
  final Widget customBackground;
  final List<String> textList;

  @override
  _LoginState createState() => _LoginState();
}

class _LoginState extends State<Login> {
  bool rememberMe = false;

  TextEditingController emailInputController = TextEditingController();
  TextEditingController passwordInputController = TextEditingController();

  final GlobalKey<FormState> loginFormKey = GlobalKey<FormState>();

  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();

  String currentLanguage = "en";

  TranslationStream translationStream = TranslationStream();

  bool _passwordVisible = false;

  SharedPreferences prefs;

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();

    if (prefs.getString("email") != null) {
      emailInputController.text = prefs.getString("email");
      rememberMe = true;
      setState(() {});
    }
  }

  updateTextList(int index, String newText) {
    widget.textList[index] = newText;
    setState(() {});
  }

  languagePickerCallback(String newCurrentLanguage) async {
    currentLanguage = newCurrentLanguage;
    translationStream.translate();
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
    translationStream.init(widget.textList, updateTextList);
    translationStream.translate();

    //widget

    Map<String, String> urlParams = Uri.base.queryParameters;

    print("urlParams: " + urlParams.toString());
    print("Uri.base: " + Uri.base.toString());
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    double sizedBoxSpace = 20;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: true,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: widget.topbarBackgroundColor,
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: widget.languagePicker
                  ? LanguagePicker(
                      currentLanguage: currentLanguage,
                      parentWidget: this,
                      function: languagePickerCallback,
                      languagePickerItemsTextColor:
                          widget.languagePickerItemsTextColor,
                    )
                  : Container(),
            ),
          ],
          customLeading: null,
          logoImage: "",
        ),
      ),
      body: UserInfoFormContainer(
        userInfoFormType: UserInfoFormType.login,
        cardColor: widget.cardColor,
        cardElevation: widget.cardElevation,
        backgroundImagePath: widget.backgroundImagePath,
        linearGradient: LinearGradient(
          begin: FractionalOffset.bottomRight,
          end: FractionalOffset.topLeft,
          colors: [
            widget.userInfoFormContainerColor1,
            widget.userInfoFormContainerColor2,
            widget.userInfoFormContainerColor3,
          ],
          stops: [
            0.0,
            0.4,
            1.0,
          ],
        ),
        customBackground: widget.customBackground,
        children: [
          Container(
            height: 100,
            width: 300,
            decoration: BoxDecoration(
              image: DecorationImage(
                fit: BoxFit.contain,
                image: AssetImage(
                  "assets/images/emissor_logo_with_colors.png",
                ),
              ),
            ),
          ),
          SizedBox(
            height: sizedBoxSpace * 2,
          ),
          TextFormField(
            decoration: InputDecoration(
              labelText: widget.textList[0],
              labelStyle: TextStyle(
                color: widget.rememberMeColor,
              ),
            ),
            controller: emailInputController,
            validator: (String value) => FormFieldValidators(
              value: value,
              type: FormFieldValidatorsType.email,
            ).validate(),
          ),
          SizedBox(
            height: sizedBoxSpace,
          ),
          TextFormField(
            decoration: InputDecoration(
              labelText: widget.textList[1],
              labelStyle: TextStyle(
                color: widget.rememberMeColor,
              ),
              suffixIcon: IconButton(
                icon: Icon(
                  // Based on passwordVisible state choose the icon
                  _passwordVisible
                      ? Icons.visibility
                      : Icons.visibility_off,
                  color: Theme.of(context).primaryColorDark,
                ),
                onPressed: () {
                  // Update the state i.e. toogle the state of passwordVisible variable
                  setState(() {
                    _passwordVisible = !_passwordVisible;
                  });
                },
              ),
            ),
            controller: passwordInputController,
            validator: (String value) => FormFieldValidators(
              value: value,
              type: FormFieldValidatorsType.password,
            ).validate(),
            obscureText: !_passwordVisible,
          ),
          SizedBox(
            height: sizedBoxSpace,
          ),
          FlatButton(
            padding: EdgeInsets.all(0),
            onPressed: () {
              rememberMe = !rememberMe;
              setState(() {});
            },
            child: Row(
              children: <Widget>[
                Container(
                  child: Icon(
                    rememberMe
                        ? Icons.check_box
                        : Icons.check_box_outline_blank,
                    color: widget.rememberMeColor,
                  ),
                  margin: EdgeInsets.only(
                    right: 10,
                  ),
                ),
                Text(
                  widget.textList[2],
                  style: TextStyle(
                    color: widget.rememberMeColor,
                  ),
                ),
              ],
            ),
          ),
          SizedBox(
            height: sizedBoxSpace,
          ),
          Container(
            width: MediaQuery.of(context).size.width,
            height: 60,
            child: CustomCard(
              borderRadius: MediaQuery.of(context).size.width,
              elevation: 7,
              onPressed: () {
                List<TextEditingController> inputControllers = [
                  emailInputController,
                  passwordInputController,
                ];

                UserInfoFormFunctions().login(
                  context: context,
                  scaffoldKey: scaffoldKey,
                  rememberMe: rememberMe,
                  loginFormKey: loginFormKey,
                  inputControllers: inputControllers,
                  prefs: prefs,
                  openHome: widget.openHome,
                );
              },
              linearGradient: widget.loginButtonGradientColor,
              color: widget.loginButtonColor,
              child: Center(
                child: Text(
                  widget.textList[3],
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: Colors.white,
                    fontSize: 16,
                    fontWeight: FontWeight.bold,
                  ),
                ),
              ),
            ),
          ),
          SizedBox(
            height: sizedBoxSpace,
          ),
          Flex(
            direction: isLandscape ? Axis.horizontal : Axis.vertical,
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              FlatButton(
                onPressed: () {
                  widget.openForgotPassword();
                },
                child: Text(
                  widget.textList[4],
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: widget.forgotButtonColor,
                    fontSize: 12,
                    //fontWeight: FontWeight.bold,
                  ),
                ),
              ),
              FlatButton(
                onPressed: () {
                  widget.openRegister();
                },
                child: Text(
                  widget.textList[5],
                  textAlign: TextAlign.center,
                  style: TextStyle(
                    color: widget.registerButtonColor,
                    fontSize: 12,
                    //fontWeight: FontWeight.bold,
                  ),
                ),
              ),
            ],
          ),
        ],
      ),
    );
  }
}
